@@ -32,8 +32,10 @@ class JsRegex
         return node if node.dropped? || (qtf = expression.quantifier).nil?
 
         if qtf.possessive?
-          node.update(quantifier: qtf.text[0..-2])
+          node.update(quantifier: qtf.dup.tap { |q| q.text = q.text[0..-2] })
           return wrap_in_backrefed_lookahead(node)
+        elsif qtf.token == :interval && qtf.text[0..1] == "{,"
+          node.update(quantifier: qtf.dup.tap { |q| q.text = "{0,#{q.max}}" })
         else
           node.update(quantifier: qtf)
         end
@@ -49,10 +51,14 @@ class JsRegex
         Converter.convert(expression, context)
       end
 
-      def warn_of_unsupported_feature(description = nil)
+      def warn_of_unsupported_feature(description = nil, min_target: nil)
         description ||= "#{subtype} #{expression.type}".tr('_', ' ')
-        full_desc = "#{description} '#{expression}'"
-        warn_of("Dropped unsupported #{full_desc} at index #{expression.ts}")
+        full_text = "Dropped unsupported #{description} '#{expression}' "\
+                    "at index #{expression.ts}"
+        if min_target
+          full_text += " (requires at least `target: '#{min_target}'`)"
+        end
+        warn_of(full_text)
         drop
       end
 
@@ -66,11 +72,11 @@ class JsRegex
       alias drop_without_warning drop
 
       def wrap_in_backrefed_lookahead(content)
-        backref_num = context.capturing_group_count + 1
-        backref_num_node = Node.new(backref_num.to_s, type: :backref_num)
+        number = context.capturing_group_count + 1
+        backref_node = Node.new("\\#{number}", reference: number, type: :backref)
         context.increment_local_capturing_group_count
         # an empty passive group (?:) is appended as literal digits may follow
-        Node.new('(?=(', *content, '))\\', backref_num_node, '(?:)')
+        Node.new('(?=(', *content, '))', backref_node, '(?:)')
       end
     end
   end
