@@ -7,11 +7,15 @@ class JsRegex
     #
     class LiteralConverter < JsRegex::Converter::Base
       class << self
-        ASTRAL_PLANE_CODEPOINT_PATTERN = /[\u{10000}-\u{FFFFF}]/
+        ASTRAL_PLANE_CODEPOINT_PATTERN = /[\u{10000}-\u{10FFFF}]/
 
-        def convert_data(data)
+        def convert_data(data, context)
           if data =~ ASTRAL_PLANE_CODEPOINT_PATTERN
-            convert_astral_data(data)
+            if context.enable_u_option
+              escape_incompatible_bmp_literals(data)
+            else
+              convert_astral_data(data)
+            end
           else
             escape_incompatible_bmp_literals(data)
           end
@@ -41,7 +45,7 @@ class JsRegex
       private
 
       def convert_data
-        result = self.class.convert_data(data)
+        result = self.class.convert_data(data, context)
         if context.case_insensitive_root && !expression.case_insensitive?
           warn_of_unsupported_feature('nested case-sensitive literal')
         elsif !context.case_insensitive_root && expression.case_insensitive?
