@@ -9,10 +9,11 @@ class JsRegex
     attr_reader :children, :quantifier, :reference, :type
 
     TYPES = %i[
-      backref_num
+      backref
       captured_group
       conditional
       dropped
+      keep_mark
       plain
     ].freeze
 
@@ -46,7 +47,7 @@ class JsRegex
       case type
       when :dropped
         ''
-      when :backref_num, :captured_group, :plain
+      when :backref, :captured_group, :plain
         children.join << quantifier.to_s
       else
         raise TypeError.new(
@@ -59,10 +60,35 @@ class JsRegex
       self.children   = attrs.fetch(:children)   if attrs.key?(:children)
       self.quantifier = attrs.fetch(:quantifier) if attrs.key?(:quantifier)
       self.type       = attrs.fetch(:type)       if attrs.key?(:type)
+      self
     end
 
     private
 
-    attr_writer :children, :reference, :quantifier, :type
+    TypeError = Class.new(::TypeError).extend(JsRegex::Error)
+
+    def type=(arg)
+      arg.nil? || TYPES.include?(arg) ||
+        raise(TypeError, "unsupported type #{arg.class} for #{__method__}")
+      @type = arg
+    end
+
+    def children=(arg)
+      arg.class == Array ||
+        raise(TypeError, "unsupported type #{arg.class} for #{__method__}")
+      @children = arg
+    end
+
+    def quantifier=(arg)
+      arg.nil? || arg.class == Regexp::Expression::Quantifier ||
+        raise(TypeError, "unsupported type #{arg.class} for #{__method__}")
+      @quantifier = arg
+    end
+
+    def reference=(arg)
+      arg.nil? || arg.is_a?(Numeric) ||
+        raise(TypeError, "unsupported type #{arg.class} for #{__method__}")
+      @reference = arg
+    end
   end
 end
